@@ -10,6 +10,8 @@
 #' @slot index parameter index, integer
 #' @slot value parameter value (e.g. the estimated value from a modelling tool)
 #' @slot fix logical value, say if parameter was fixed in the modelling phase
+#' @slot label parameter label, any string
+#' @slot comment any comment on this parameter, any string
 #' @export
 setClass(
   "parameter",
@@ -17,12 +19,15 @@ setClass(
     name = "character",
     index = "integer",
     value = "numeric",
-    fix = "logical"
+    fix = "logical",
+    label = "character",
+    comment = "character"
   ),
   contains = "pmx_element",
-  prototype = prototype(name=as.character(NA), index=as.integer(NA), value=as.numeric(NA), fix=FALSE),
+  prototype = prototype(name=as.character(NA), index=as.integer(NA), value=as.numeric(NA), fix=FALSE,
+                        label=as.character(NA), unit=as.character(NA), comment=as.character(NA)),
   validity = function(object) {
-    check <- expectOneForAll(object, c("name", "index", "fix", "value"))
+    check <- expectOneForAll(object, c("name", "index", "fix", "value", "label", "comment"))
     return(check)
   }
 )
@@ -94,10 +99,12 @@ setClass(
 #' 
 #' Theta parameter class.
 #' 
+#' @slot unit parameter unit
 #' @export
 setClass(
   "theta",
   representation(
+    unit = "character"
   ),
   contains = "single_array_parameter"
 )
@@ -109,10 +116,14 @@ setClass(
 #' @param index parameter index
 #' @param value parameter value
 #' @param fix parameter was fixed in estimation, logical value
+#' @param label parameter label, optional
+#' @param unit parameter unit, optional
+#' @param comment any comment, optional
 #' @return a THETA parameter  
 #' @export
-Theta <- function(name=NA, index=NA, value=NA, fix=FALSE) {
-  return(new("theta", name=as.character(name), index=as.integer(index), value=as.numeric(value), fix=fix))
+Theta <- function(name=NA, index=NA, value=NA, fix=FALSE, label=NA, unit=NA, comment=NA) {
+  return(new("theta", name=as.character(name), index=as.integer(index), value=as.numeric(value), fix=fix,
+             label=as.character(label), unit=as.character(unit), comment=as.character(comment)))
 }
 
 #_______________________________________________________________________________
@@ -170,12 +181,15 @@ processDoubleArrayArguments <- function(index, index2, type) {
 #' @param fix parameter was fixed in estimation, logical value
 #' @param type variance type: 'var', 'sd', 'covar', 'cor', 'cv' or 'cv\%'
 #' @param same NA by default, FALSE for first OMEGA followed by 'SAME' OMEGA's, TRUE for 'SAME' OMEGA's
+#' @param label parameter label, optional
+#' @param comment any comment, optional
 #' @return an OMEGA parameter  
 #' @export
-Omega <- function(name=NA, index=NA, index2=NA, value=NA, fix=FALSE, type=NULL, same=NA) {
+Omega <- function(name=NA, index=NA, index2=NA, value=NA, fix=FALSE, type=NULL, same=NA, label=NA, comment=NA) {
   type <- processDoubleArrayArguments(index=index, index2=index2, type=type)
   return(new("omega", name=as.character(name), index=as.integer(index), index2=as.integer(index2),
-             value=as.numeric(value), fix=fix, type=type, same=as.logical(same)))
+             value=as.numeric(value), fix=fix, type=type, same=as.logical(same),
+             label=as.character(label), comment=as.character(comment)))
 }
 
 #_______________________________________________________________________________
@@ -201,12 +215,15 @@ setClass(
 #' @param value parameter value
 #' @param fix parameter was fixed in estimation, logical value
 #' @param type variance type: 'var', 'sd', 'covar', 'cv' or 'cv\%'
+#' @param label parameter label, optional
+#' @param comment any comment, optional
 #' @return a SIGMA parameter  
 #' @export
-Sigma <- function(name=NA, index=NA, index2=NA, value=NA, fix=FALSE, type=NULL) {
+Sigma <- function(name=NA, index=NA, index2=NA, value=NA, fix=FALSE, type=NULL, label=NA, comment=NA) {
   type <- processDoubleArrayArguments(index=index, index2=index2, type=type)
   return(new("sigma", name=as.character(name), index=as.integer(index), index2=as.integer(index2),
-             value=as.numeric(value), fix=fix, type=type))
+             value=as.numeric(value), fix=fix, type=type,
+             label=as.character(label), comment=as.character(comment)))
 }
 
 #_______________________________________________________________________________
@@ -232,17 +249,17 @@ setGeneric("as.data.frame", function(x, row.names=NULL, optional=FALSE, ...) {
 
 #' @rdname as.data.frame
 setMethod("as.data.frame", signature("theta", "character", "logical"), function(x, row.names=NULL, optional=FALSE, ...) {
-  return(data.frame(name=x@name, index=x@index, value=x@value, fix=x@fix))
+  return(data.frame(name=x@name, index=x@index, value=x@value, fix=x@fix, label=x@label, unit=x@unit, comment=x@comment))
 })
 
 #' @rdname as.data.frame
 setMethod("as.data.frame", signature("omega", "character", "logical"), function(x, row.names=NULL, optional=FALSE, ...) {
-  return(data.frame(name=x@name, index=x@index, index2=x@index2, value=x@value, fix=x@fix, type=x@type, same=x@same))
+  return(data.frame(name=x@name, index=x@index, index2=x@index2, value=x@value, fix=x@fix, type=x@type, same=x@same, label=x@label, comment=x@comment))
 })
 
 #' @rdname as.data.frame
 setMethod("as.data.frame", signature("sigma", "character", "logical"), function(x, row.names=NULL, optional=FALSE, ...) {
-  return(data.frame(name=x@name, index=x@index, index2=x@index2, value=x@value, fix=x@fix, type=x@type))
+  return(data.frame(name=x@name, index=x@index, index2=x@index2, value=x@value, fix=x@fix, type=x@type, label=x@label, comment=x@comment))
 })
 
 #_______________________________________________________________________________
